==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/EventArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.EventArgument;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;

import java.util.Arrays;
import java.util.List;


public class EventArgumentSetImpl extends InstanceSet<EventArgumentSet,EventArgument> implements EventArgumentSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setSMedi_ID( ref_SMedi_ID );
    }
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( EventArgument eventargument : this ) messageargumentset.add( eventargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public StateMachineEventDataItemSet R1017_is_represented_by_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( EventArgument eventargument : this ) statemachineeventdataitemset.add( eventargument.R1017_is_represented_by_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }


    @Override
    public EventArgument nullElement() {
        return EventArgumentImpl.EMPTY_EVENTARGUMENT;
    }

    @Override
    public EventArgumentSet emptySet() {
      return new EventArgumentSetImpl();
    }

    @Override
    public EventArgumentSet value() {
        return this;
    }

    @Override
    public List<EventArgument> elements() {
        return Arrays.asList(toArray(new EventArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/EventArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.message.EventArgument;
import io.ciera.tool.sql.ooaofooa.message.EventArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.StateMachineEventDataItemSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.StateMachineEventDataItemSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class EventArgumentSetImpl extends InstanceSet<EventArgumentSet,EventArgument> implements EventArgumentSet {

    public EventArgumentSetImpl() {
    }

    public EventArgumentSetImpl(Comparator<? super EventArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMedi_ID( UniqueId ref_SMedi_ID ) throws XtumlException {
        for ( EventArgument eventargument : this ) eventargument.setSMedi_ID( ref_SMedi_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( EventArgument eventargument : this ) messageargumentset.add( eventargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public StateMachineEventDataItemSet R1017_is_represented_by_StateMachineEventDataItem() throws XtumlException {
        StateMachineEventDataItemSet statemachineeventdataitemset = new StateMachineEventDataItemSetImpl();
        for ( EventArgument eventargument : this ) statemachineeventdataitemset.add( eventargument.R1017_is_represented_by_StateMachineEventDataItem() );
        return statemachineeventdataitemset;
    }


    @Override
    public EventArgument nullElement() {
        return EventArgumentImpl.EMPTY_EVENTARGUMENT;
    }

    @Override
    public EventArgumentSet emptySet() {
      return new EventArgumentSetImpl();
    }

    @Override
    public EventArgumentSet emptySet(Comparator<? super EventArgument> comp) {
      return new EventArgumentSetImpl(comp);
    }

    @Override
    public EventArgumentSet value() {
        return this;
    }

    @Override
    public List<EventArgument> elements() {
        return Arrays.asList(toArray(new EventArgument[0]));
    }

}
